<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Maryland";
    var qsoPartyUrl = "http://mdcqsoparty.w3vpr.org/";
    var overlayUrl = "http://www.no5w.com/OverlayMaryland-DCRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Allegany", "aly");
  countySelection.options[1] = new Option("AnneArundel", "ana");
  countySelection.options[2] = new Option("Baltimore", "bco");
  countySelection.options[3] = new Option("BaltimoreCity", "bal");
  countySelection.options[4] = new Option("Calvert", "clv");
  countySelection.options[5] = new Option("Caroline", "cln");
  countySelection.options[6] = new Option("Carroll", "crl");
  countySelection.options[7] = new Option("Cecil", "cec");
  countySelection.options[8] = new Option("Charles", "chs");
  countySelection.options[9] = new Option("Dorchester", "drc");
  countySelection.options[10] = new Option("Frederick", "frd");
  countySelection.options[11] = new Option("Garrett", "gar");
  countySelection.options[12] = new Option("Harford", "hfd");
  countySelection.options[13] = new Option("Howard", "hwd");
  countySelection.options[14] = new Option("Kent", "ken");
  countySelection.options[15] = new Option("Montgomery", "mon");
  countySelection.options[16] = new Option("PrinceGeorges", "pge");
  countySelection.options[17] = new Option("QueenAnnes", "qan");
  countySelection.options[18] = new Option("Somerset", "smr");
  countySelection.options[19] = new Option("StMarys", "stm");
  countySelection.options[20] = new Option("Talbot", "tal");
  countySelection.options[21] = new Option("Washington", "was");
  countySelection.options[22] = new Option("WashingtonDC", "wdc");
  countySelection.options[23] = new Option("Wicomico", "wic");
  countySelection.options[24] = new Option("Worcester", "wrc");
  addMarker(39.58060000, -78.69060000, "Allegany", "aly");
  addMarker(38.97430000, -76.59490000, "AnneArundel", "ana");
  addMarker(39.43900000, -76.59160000, "Baltimore", "bco");
  addMarker(39.28470000, -76.62050000, "BaltimoreCity", "bal");
  addMarker(38.53710000, -76.51190000, "Calvert", "clv");
  addMarker(38.88940000, -75.86120000, "Caroline", "cln");
  addMarker(39.53470000, -77.04930000, "Carroll", "crl");
  addMarker(39.54150000, -75.99990000, "Cecil", "cec");
  addMarker(38.43870000, -76.99280000, "Charles", "chs");
  addMarker(38.38130000, -76.07020000, "Dorchester", "drc");
  addMarker(39.47010000, -77.39200000, "Frederick", "frd");
  addMarker(39.46250000, -79.20940000, "Garrett", "gar");
  addMarker(39.48780000, -76.30260000, "Harford", "hfd");
  addMarker(39.23620000, -76.94180000, "Howard", "hwd");
  addMarker(39.19900000, -76.05540000, "Kent", "ken");
  addMarker(39.14390000, -77.20800000, "Montgomery", "mon");
  addMarker(38.83330000, -76.87950000, "PrinceGeorges", "pge");
  addMarker(39.03460000, -76.09220000, "QueenAnnes", "qan");
  addMarker(38.09270000, -75.88800000, "Somerset", "smr");
  addMarker(38.20110000, -76.53800000, "StMarys", "stm");
  addMarker(38.75850000, -76.18010000, "Talbot", "tal");
  addMarker(39.52060000, -77.91630000, "Washington", "was");
  addMarker(38.89360000, -77.01460000, "WashingtonDC", "wdc");
  addMarker(38.38840000, -75.62770000, "Wicomico", "wic");
  addMarker(38.22310000, -75.32410000, "Worcester", "wrc");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

